<?php
// $Id: latestposts_handler_field_user_latest_posts.inc,v 1.1 2009/02/21 13:31:58 seutje Exp $
/**
 *@file
 *The actual handler that provides the latest post(s) made by a user.
 */

/**
 * Field handler to provide the latest post(s) made by a user.
 */
class latestposts_handler_field_user_latest_posts extends views_handler_field {
  function construct() {
    parent::construct();
    $this->additional_fields['uid'] = 'uid';
  }

  function option_definition() {
    $options = parent::option_definition();
    $options['contenttype'] = array('default' => array());
    $options['amount'] = array('default' => '1', 'translatable' => FALSE);
    $options['nonetext'] = array('default' => 'none', 'translatable' => TRUE);
    $options['orderstyle'] = array('default' => 'created');
    return $options;
  }
  
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    $types = array();
    $result = db_query('SELECT type, name from {node_type}');
    while ($contenttype = db_fetch_object($result)) {
      $types[$contenttype->type] = $contenttype->name;
    }
    $form['contenttype'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Content types to include'),
      '#default_value' => $this->options['contenttype'],
      '#options' => $types,
      '#description' => t('Choose at least 1 content type'),
    );
    $form['amount'] = array(
      '#type' => 'textfield',
      '#title' => t('Amount to display'),
      '#default_value' => $this->options['amount'],
    );
    $form['nonetext'] = array(
      '#type' => 'textfield',
      '#title' => t('Empty list text'),
      '#default_value' => $this->options['nonetext'],
    );
    $form['orderstyle'] = array(
      '#type' => 'radios',
      '#title' => t('Order on'),
      '#options' => array(
        'created' => t('Date created'),
        'changed' => t('Date latest change'),
        'nid' => t('Node ID'),
      ),
      '#default_value' => $this->options['orderstyle'],
    );
  }

  function query() {
    $this->ensure_my_table();
    $this->add_additional_fields();
  }

  function render($values) {
    if (is_numeric($this->options['amount'])) {
      $amount = $this->options['amount'];
    }
    else {
      $amount = 1;
    }
    foreach ($this->options['contenttype'] as $type) {
      if ($type) {
        $types[] = $type;
      }
    }
    $uid = $values->{$this->aliases['uid']};
    switch ($this->options['orderstyle']) {
      case "nid":
        $sql = "SELECT n.nid FROM {node} n WHERE n.status = 1 AND n.uid IN (%d) AND n.type IN ('". implode("','", $types) ."') ORDER BY n.nid DESC";
        break;
      case "changed":
        $sql = "SELECT n.nid FROM {node} n WHERE n.status = 1 AND n.uid IN (%d) AND n.type IN ('". implode("','", $types) ."') ORDER BY n.changed DESC";
        break;
      default:
        $sql = "SELECT n.nid FROM {node} n WHERE n.status = 1 AND n.uid IN (%d) AND n.type IN ('". implode("','", $types) ."') ORDER BY n.created DESC";
    }
    $result = db_query_range(db_rewrite_sql($sql, 'n', 'uid'), $uid, 0, $amount);
    while ($nid = db_fetch_object($result)) {
      $node = node_load($nid->nid);
      if (node_access('view', $node)) {
        $items[] = l($node->title, drupal_get_path_alias('node/'. $node->nid));
      }
    }
    if ($items) {
      $return = implode(', ', $items);
    }
    else {
      $return = $this->options['nonetext'];
    }
    
    if ($return) {
      return $return;
    }
  }
}
